@@ -16,7 +16,7 @@
     of each symbol. The result, that is symbol based, is a tuple containing
     two entries: local declarations, and actual code. This allows the
     backend template to organize easily the layout of the code.
-    These functions are suffixed with "Statement" (e.g. output_statement).
+    These functions are suffixed with "statement" (e.g. output_statement).
 
     In turn, when a symbol encounters an expression (assignment, field access,
     embedded constructs), recursive functions (prefixed with "decipher")
@@ -174,11 +174,13 @@ def write_statement(param, newline):
     if type_kind.endswith('StringType'):
         if param.var.kind == 'stringLiteral':
             # Raw string
-            string = '"' + param.var.stringLiteral[1:-1] + '"'
+            string =('"' +
+                     param.var.stringLiteral[1:-1].replace('"', "'") + '"')
         else:
             # XXX Cannot print an octet string like that...
             code, string, local = decipher_expression(param)
-    elif type_kind in ('IntegerType', 'RealType', 'BooleanType'):
+    elif type_kind in ('IntegerType', 'RealType',
+                       'BooleanType', 'Integer32Type'):
         code, string, local = decipher_expression(param)
         if type_kind == 'IntegerType':
             cast = "Interfaces.Integer_64"
@@ -186,6 +188,8 @@ def write_statement(param, newline):
             cast = 'Long_Float'
         elif type_kind == 'BooleanType':
             cast = 'Boolean'
+        elif type_kind == 'Integer32Type':
+            cast = 'Integer'
         string = "{cast}'Image({s})".format(cast=cast, s=string)
     else:
         error = ('Unsupported parameter in write call ' +
@@ -315,7 +319,7 @@ def output_statement(output):
 
 
 def task_statement(task):
-    ''' generate the code of a task (set of assign) '''
+    ''' generate the code of a task (assign or FOR loop) '''
     code = []
     local_decl = []
     if task.comment:
@@ -345,11 +349,97 @@ def task_statement(task):
             local_decl.extend(left_local)
             local_decl.extend(right_local)
             code.append(assign_str)
+    elif task.kind == 'for_loop':
+        code.extend(traceability(task))
+        for loop in task.forloop:
+            loop_stmt, loop_local = decipher_forloop(loop)
+            code.extend(loop_stmt)
+            local_decl.extend(loop_local)
     else:
-        raise ValueError('task kind is unknown: ' + task.kind)
+        raise ValueError('task kind is unknown or unsupported: ' + task.kind)
     return code, local_decl
 
 
+def decipher_forloop(loop):
+    '''
+        Return the code corresponding to a for loop. Two forms are possible:
+        for x in range ([start], stop [, step])
+        for x in iterable (a SEQUENCE OF)
+    '''
+    stmt = []
+    local_decl = []
+
+    if loop['range']:
+        start_str, stop_str = '0', ''
+        if loop['range']['start']:
+            start_stmt, start_str, start_local = decipher_expression\
+                                                     (loop['range']['start'])
+            local_decl.extend(start_local)
+            stmt.extend(start_stmt)
+            # ASN.1 Integers are 64 bits - we need to convert to 32 bits
+            if loop['range']['start'].var.kind == 'primaryId':
+                start_str = 'Integer({})'.format(start_str)
+        if loop['range']['step'] == 1:
+            start_str += '..'
+        stop_stmt, stop_str, stop_local = decipher_expression\
+                                            (loop['range']['stop'])
+        local_decl.extend(stop_local)
+        stmt.extend(stop_stmt)
+        if loop['range']['stop'].var.kind == 'primaryId':
+            stop_str = 'Integer({})'.format(stop_str)
+        if loop['range']['step'] == 1:
+            stmt.append(
+                    'for {it} in {start}{stop} loop'
+                    .format(it=loop['var'], start=start_str, stop=stop_str))
+        else:
+            # Step is not directly supported in Ada, we need to use 'while'
+            stmt.extend(['declare',
+                         '{it} : Integer := {start};'.format(it=loop['var'],
+                                                             start=start_str),
+                         '',
+                         'begin',
+                         'while {it} < {stop} loop'.format(it=loop['var'],
+                                                           stop=stop_str)])
+    else:
+        # case of form: FOR x in SEQUENCE OF
+        elem_type = loop['type'].ReferencedTypeName.replace('-', '_')
+        list_stmt, list_str, list_local = decipher_primary(loop['list'])
+        basic_type = find_basic_type(loop['list'].primType)
+        range_cond = "{}.Data'Range".format(list_str)\
+                if basic_type.Min == basic_type.Max\
+                else "1..{}.Length".format(list_str)
+        stmt.extend(list_stmt)
+        local_decl.extend(list_local)
+        stmt.extend(['declare',
+                     '{it} : asn1Scc{it_ty};'.format(it=loop['var'],
+                                                     it_ty=elem_type),
+                     '',
+                     'begin',
+                     'for {it}_idx in {rc} loop'.format(it=loop['var'],
+                                                        rc=range_cond),
+                     '{it} := {var}.Data({it}_idx);'.format(it=loop['var'],
+                                                            var=list_str)])
+    try:
+        code_trans, local_trans = transition(loop['transition'])
+        if local_trans:
+            stmt.append('declare')
+            stmt.extend(local_trans)
+            stmt.append('')
+            stmt.append('begin')
+        stmt.extend(code_trans)
+        if local_trans:
+            stmt.append('end;')
+    except AttributeError:
+        stmt.append('null;')
+    if loop['range'] and loop['range']['step'] != 1:
+        stmt.append('{it} := {it} + {step};'.format(it=loop['var'],
+                                                   step=loop['range']['step']))
+    stmt.append('end loop;')
+    if (loop['range'] and loop['range']['step'] != 1) or loop['list']:
+        stmt.append('end;')
+    return stmt, local_decl
+
+
 def decipher_primary_id(primaryId):
     '''
         Return the Ada string of a PrimaryId element list (path)
@@ -376,6 +466,9 @@ def decipher_primary_id(primaryId):
             elif pr_id.lower() == 'present':
                 special_op = 'ChoiceKind'
                 continue
+            elif pr_id.lower() == 'abs':
+                special_op = 'Abs'
+                continue
             special_op = ''
             parent_kind, parent_typename = path_type(sub_id)
             sub_id.append(pr_id)
@@ -406,9 +499,9 @@ def decipher_primary_id(primaryId):
                 # XXX types with fixed length: substrings will not work
                 if unicode.isnumeric(r1_string) and unicode.isnumeric(
                                                                 r2_string):
-                    length = eval(r2_string + '-' + r1_string + '+1')
+                    length = int(r2_string) - int(r1_string) + 1
                 else:
-                    length = ('{r2} - {r1} +1'
+                    length = ('{r2} - {r1} + 1'
                         .format(r2=r2_string, r1=r1_string))
                 stmts.append('tmp{idx}.Length := {length};'
                         .format(idx=pr_id['tmpVar'], length=length))
@@ -422,14 +515,29 @@ def decipher_primary_id(primaryId):
                 idx_stmts, idx_string, local_var = decipher_expression(
                         pr_id['index'][0])
                 if unicode.isnumeric(idx_string):
-                    idx_string = eval(idx_string + '+1')
+                    idx_string = int(idx_string) + 1
                 else:
                     idx_string = '1+({idx})'.format(idx=idx_string)
                 ada_string += '.Data({idx})'.format(idx=idx_string)
                 stmts.extend(idx_stmts)
                 local_decl.extend(local_var)
             elif 'procParams' in pr_id:
-                if special_op == 'Length':
+                if special_op == 'Abs':
+                    # Return absolute value of a number
+                    exp, = pr_id['procParams']
+                    exp_type = find_basic_type(exp.exprType)
+                    if exp_type.kind not in ('IntegerType', 'RealType'):
+                        error = ('{} must be a number to return absolute value'
+                                .format(exp.inputString))
+                        LOG.error(error)
+                        raise TypeError(error)
+                    param_stmts, param_str, local_var = decipher_expression(
+                                                                           exp)
+                    stmts.extend(param_stmts)
+                    local_decl.extend(local_var)
+                    ada_string += 'abs(' + param_str + ')'
+
+                elif special_op == 'Length':
                     # Length of sequence of: take only the first parameter
                     exp, = pr_id['procParams']
                     exp_type = find_basic_type(exp.exprType)
@@ -620,7 +728,8 @@ def decipher_primary(primary):
     elif primary.kind == 'choiceDeterminant':
         enumerant = primary.primaryId[0].replace('_', '-')
         ada_string = primary.primType.EnumValues[enumerant].EnumID
-    elif primary.kind in ('numericalValue', 'booleanValue'):
+    elif primary.kind in (
+            'numericalValue_int', 'numericalValue_float', 'booleanValue'):
         ada_string = primary.primaryId[0]
     elif primary.kind == 'sequence':
         stmts, ada_string, local_decl = decipher_sequence(
@@ -925,6 +1034,7 @@ def transition(tr):
             # Transition following labels are generated in a separate section
             # for visibility reasons (see Ada scope)
             code.append('goto {label};'.format(label=action.inputString))
+            empty_transition = False
             break
     else:
         if tr.terminator:
@@ -961,8 +1071,10 @@ def floating_label(label):
     code.append('<<{label}>>'.format(label=label.inputString))
     if label.transition:
         code_trans, local_trans = transition(label.transition)
-    code.extend(code_trans)
-    local_decl.extend(local_trans)
+        code.extend(code_trans)
+        local_decl.extend(local_trans)
+    else:
+        code.append('return;')
     return code, local_decl
 
 
@@ -1043,12 +1155,13 @@ def format_ada_code(stmts):
     indent_pattern = '    '
     for line in stmts[:-1]:
         elems = line.strip().split()
-        if elems and elems[0] in ('when', 'end', 'elsif', 'else'):
+        if elems and elems[0].startswith(('when', 'end', 'elsif', 'else')):
             indent = max(indent - 1, 0)
         if elems and elems[-1] == 'case;': # Corresponds to end case;
             indent = max(indent - 1, 0)
-        yield indent_pattern * indent + line
-        if elems and elems[-1] in ('is', 'then', 'loop'):
+        if line:
+            yield indent_pattern * indent + line
+        if elems and elems[-1] in ('is', 'then', 'loop', 'declare'):
             indent += 1
         if elems and elems[0] in ('begin', 'case', 'else', 'when'):
             indent += 1
