@@ -42,8 +42,8 @@ def copy(selection):
         # When several items are selected, take the first of each subbranch
         if item.hasParent and not item.parentItem().grabber.isSelected():
             branch_top_level.append(item)
-        elif not item.hasParent and not item.is_singleton:
-            # Take also floating items, if they allow for copy (e.g. not START)
+        elif not item.hasParent:# and not item.is_singleton:
+            # Take also floating items //, if they allow for copy (e.g. not START)
             floating_items.append(item)
     # Check if selected items would allow a paste - reject copy otherwise
     # e.g. floating and non-floating items cannot be pasted together
@@ -102,7 +102,10 @@ def paste(parent, scene):
     '''
     CLIPBOARD.clear()
     if not parent:
-        new_symbols = paste_floating_objects(scene)
+        try:
+            new_symbols = paste_floating_objects(scene)
+        except TypeError:
+            raise
     else:
         new_symbols = paste_below_item(parent, scene)
     return new_symbols
@@ -110,14 +113,15 @@ def paste(parent, scene):
 
 def paste_floating_objects(scene):
     ''' Paste items with no parents (states, text areas) '''
-    symbols = set()
+    symbols = []
     LOG.debug('PASTING FLOATING OBJECTS')
 
     for item_list, terminators in COPY_PASTE:
         # states is a list passed as parameter - not a generator:
+        start = [i for i in item_list if isinstance(i, ogAST.Start)]
         states = [i for i in item_list if isinstance(i, ogAST.State)]
-        text_areas = (i for i in item_list if
-                isinstance(i, ogAST.TextArea))
+        text_areas = (i for i in item_list if isinstance(i, ogAST.TextArea))
+        labels = (i for i in item_list if isinstance(i, ogAST.Floating_label))
         for state in states:
             # First check if state has already been pasted
             try:
@@ -128,20 +132,32 @@ def paste_floating_objects(scene):
                 pass
             else:
                 LOG.debug('PASTE STATE "' + state.inputString + '"')
-                symbols.add(new_item)
+                symbols.append(new_item)
                 # Insert the new state at click coordinates
                 scene.addItem(new_item)
         for text_area in text_areas:
             LOG.debug('PASTE TEXT AREA')
             new_item = Renderer.render(text_area, scene)
-            symbols.add(new_item)
+            symbols.append(new_item)
+        for label in labels:
+            LOG.debug('PASTE LABEL')
+            new_item = Renderer.render(label, scene, states=states)
+            symbols.append(new_item)
+        if start:
+            start, = start
+            LOG.debug('PASTE START')
+            for item in scene.items():
+                if isinstance(item, sdlSymbols.Start) and item.isVisible():
+                    raise TypeError('Only one START symbol is possible')
+            new_item = Renderer.render(start, scene, states=states)
+            symbols.append(new_item)
     return symbols
 
 
 def paste_below_item(parent, scene):
     ''' Paste items under a selected symbol '''
-    LOG.debug('Pasting below item ' + repr(parent))
-    symbols = set()
+    LOG.debug('Pasting below item ' + repr(parent)[slice(0,20)])
+    symbols = []
     for item_list, _ in COPY_PASTE:
         states = [i for i in item_list if isinstance(i, ogAST.State)]
         for i in [c for c in item_list if not isinstance
@@ -155,7 +171,7 @@ def paste_below_item(parent, scene):
                 # Move the item from the clipboard to the scene
                 scene.addItem(new_item)
                 new_item.setPos(0, 0)
-                symbols.add(new_item)
+                symbols.append(new_item)
             else:
                 raise TypeError('Cannot paste here ({t1} cannot follow {t2}'
                                 .format(t1=type(new_item), t2=type(parent)))
