@@ -240,7 +240,7 @@ def _decision(ast, scene, parent, states):
 
 
 @render.register(ogAST.Label)
-def _label(ast, scene, parent, states):
+def _label(ast, scene, parent=None, states=None):
     ''' Create a LABEL symbol '''
     _, _ = scene, states
     return sdlSymbols.Label(parent, ast=ast)
