@@ -191,9 +191,11 @@ class EditableText(QGraphicsTextItem, object):
         Includes autocompletion when parent item needs it
     '''
     default_cursor = Qt.IBeamCursor
+    hasParent = False
 
     def __init__(self, parent, text='...', hyperlink=None):
         super(EditableText, self).__init__(parent)
+        self.setFont(QFont('Ubuntu', 8))
         self.completer = Completer(self)
         self.completer.widget().itemActivated.connect(
                 self.completion_selected)
@@ -426,6 +428,7 @@ class Connection(QGraphicsPathItem, object):
     ''' Connection between two symbols (arrow) '''
     # Default connections are not selectable
     default_cursor = Qt.ArrowCursor
+    hasParent = False
 
     def __init__(self, parent, child, connectionPoint=False):
         super(Connection, self).__init__(parent)
@@ -540,7 +543,7 @@ class Symbol(QObject, QGraphicsPathItem, object):
     arrow_head = False
     # Default mouse cursor
     default_cursor = Qt.SizeAllCursor
-    # Decide if a symbol can be copied or if only one of its kind can exist
+    # Decide if a symbol can be copy-pasted several times
     is_singleton = False
     # default textbox alignment: centered in the symbol
     # can differ on specific symbols (e.g. TextArea or label)
@@ -669,7 +672,7 @@ class Symbol(QObject, QGraphicsPathItem, object):
 
     def __str__(self):
         ''' Print the text inside the symbol '''
-        return str(self.text)
+        return str(self.text) or 'no_name'
 
     def parse_gr(self, recursive=True):
         ''' Parse the graphical representation, return PR form '''
@@ -791,6 +794,8 @@ class Symbol(QObject, QGraphicsPathItem, object):
                 # Update position of child - take place of deleted item
                 child_below.setY(self.y())
                 child_below.update_position()
+            self.parentItem().cam(self.parentItem().pos(),
+                                  self.parentItem().pos())
             self.setParentItem(None)
         # Following line cause segfault on exit:
         #scene().removeItem(self)
@@ -864,49 +869,7 @@ class Symbol(QObject, QGraphicsPathItem, object):
                 save_fmt = filename.split(os.extsep)[-1]
                 if save_fmt not in ('png', 'svg', 'pdf'):
                     return
-                old_brush = self.scene().backgroundBrush()
-                self.scene().setBackgroundBrush(QBrush())
-                complete_rect = (self.childrenBoundingRect() |
-                                self.boundingRect())
-                # Add some margin for the antialiasing (5 pixels on each side)
-                complete_rect.adjust(-5, -5, 5, 5)
-                rect = self.mapRectToScene(complete_rect)
-                self.select(False)
-
-                if save_fmt == 'png':
-                    image = QImage(rect.size().toSize(), QImage.Format_ARGB32)
-                    image.fill(Qt.transparent)
-                    painter = QPainter(image)
-                    painter.setRenderHint(QPainter.Antialiasing)
-                    self.scene().render(painter, source=rect)
-                    image.save(filename)
-                    if painter.isActive():
-                        painter.end()
-
-                elif save_fmt == 'svg':
-                    generator = QtSvg.QSvgGenerator()
-                    generator.setFileName(filename)
-                    generator.setTitle('OpenGEODE SDL Diagram')
-                    generator.setSize(rect.size().toSize())
-                    painter = QPainter()
-                    painter.begin(generator)
-                    self.scene().render(painter, source=rect)
-                    painter.end()
-
-                elif save_fmt == 'pdf':
-                    pdf_printer = QPrinter()
-                    pdf_printer.setOutputFormat(QPrinter.PdfFormat)
-                    pdf_printer.setPaperSize(
-                            rect.size().toSize(), QPrinter.Point)
-                    pdf_printer.setFullPage(True)
-                    pdf_printer.setOutputFileName(filename)
-                    pdf_painter = QPainter()
-                    pdf_painter.begin(pdf_printer)
-                    self.scene().render(pdf_painter, source=rect)
-                    pdf_painter.end()
-
-                self.scene().setBackgroundBrush(old_brush)
-                self.select(True)
+                self.scene().export_branch_to_picture(self, filename, save_fmt)
             elif action.text() == hl_action:
                 if self.text:
                     self.hyperlink_dialog.setParent(
@@ -931,11 +894,12 @@ class Symbol(QObject, QGraphicsPathItem, object):
             # if called before text is initialized - or if no textbox
             pass
         for child in self.childSymbols():
-            # note, comments will not move.. is this what we want? (FIXME)
             child.moveBy(-delta_x, -delta_y)
         # X-pos must be updated when resizing,
         # independently from update_position
         self.setPos(pos.x() + delta_x, self.y())
+        if self.comment:
+            self.comment.moveBy(-delta_x, delta_y / 2.0)
         self.update_connections()
 
     def update_connections(self):
@@ -1289,6 +1253,7 @@ class Cornergrabber(QGraphicsPolygonItem, object):
         a rectangle that covers the full parent bounding rect, allowing
         to resize it from any border/corner.
     '''
+    hasParent = False
     def __init__(self, parent):
         ''' Create the grabber '''
         super(Cornergrabber, self).__init__(parent)
