@@ -82,7 +82,8 @@ class Primary(object):
         self.charPositionInLine = charPositionInLine
         self.op_not = False
         self.op_minus = False
-        # kind can be 'primaryId', 'enumeratedValue', 'numericalValue',
+        # kind can be 'primaryId', 'enumeratedValue', 'numericalValue_int',
+        # 'numericalValue_float',
         # 'booleanValue', 'expression', 'ifThenElse', 'stringLiteral',
         # 'mantissaBaseExpFloat','emptyString' (SEQUENCE OF type value {}),
         # 'choiceItem', 'sequenceOf', 'sequence', 'choiceDeterminant',
@@ -131,13 +132,13 @@ class Decision(object):
     ''' AST Entry for a decision '''
     def __init__(self):
         ''' A DECISION statement '''
-        self.inputString = 'Switch'
+        self.inputString = ''
         self.line = None
         self.charPositionInLine = None
         self.pos_x = 0
         self.pos_y = 0
-        self.width = 100
-        self.height = 70
+        self.width = 70
+        self.height = 50
         # kind can be 'any', 'informal_text', or 'question'
         self.kind = None
         # question is an Expression
@@ -168,8 +169,8 @@ class Answer(object):
         self.charPositionInLine = None
         self.pos_x = 0
         self.pos_y = 0
-        self.width = 100
-        self.height = 35
+        self.width = 70
+        self.height = 10.5
         # one of 'closed_range' 'constant' 'open_range' 'else' 'informal_text'
         self.kind = None
         # informalText is a string, when kind == 'informal_text'
@@ -198,19 +199,23 @@ class Task(object):
     ''' AST Entry for TASKS '''
     def __init__(self):
         ''' Initialize TASK attributes (set of ASSIGN statements) '''
-        self.inputString = 'foo := 42'
+        self.inputString = 'x := 1'
         self.line = None
         self.charPositionInLine = None
         self.pos_x = 0
         self.pos_y = 0
-        self.width = 100
-        self.height = 50
-        # one of 'informal_text', 'assign'
+        self.width = 70
+        self.height = 35
+        # one of 'informal_text', 'assign', 'for_loop'
         self.kind = None
         # list of 'assign'-kind Expression
         self.assign = []
         # list of strings
         self.informalText = []
+        # list of for-loops:{'var': string, 'type': Asn1SccType,
+        # 'list': Primary, 'range': {'start': expression, 'stop': expression,
+        # 'step' : int}, 'transition': Transition }
+        self.forloop = []
         # optional comment symbol
         self.comment = None
         # optional hyperlink
@@ -224,13 +229,13 @@ class Task(object):
 
 class Output(object):
     ''' AST Entry for OUTPUT statements '''
-    def __init__(self, defName='msgOut'):
+    def __init__(self, defName='RI'):
         ''' Set of OUTPUT statements '''
         self.inputString = defName
         self.pos_x = 0
         self.pos_y = 0
-        self.width = 100
-        self.height = 50
+        self.width = 70
+        self.height = 35
         self.line = None
         self.charPositionInLine = None
         # one of 'procedure_call', 'output'
@@ -255,8 +260,8 @@ class Terminator(object):
         self.inputString = defName
         self.pos_x = None
         self.pos_y = None
-        self.width = 100
-        self.height = 50
+        self.width = 70
+        self.height = 35
         self.line = None
         self.charPositionInLine = None
         # one of 'next_state' 'join' 'stop'
@@ -284,8 +289,8 @@ class Label(object):
         self.inputString = 'Here'
         self.pos_x = 0
         self.pos_y = 0
-        self.width = 100
-        self.height = 50
+        self.width = 70
+        self.height = 35
         self.line = None
         self.charPositionInLine = None
         # optional hyperlink
@@ -294,6 +299,8 @@ class Label(object):
         self.comment = None
         # List of terminators following this label
         self.terminators = []
+        # Transition is used for floating labels (see AST entry)
+        self.transition = None
 
     def __repr__(self):
         ''' Debug output for a label '''
@@ -340,11 +347,11 @@ class Input(object):
     def __init__(self):
         ''' Initialize the Input attributes '''
         # inputString is the user text, it can contain several inputs
-        self.inputString = 'msgName'
+        self.inputString = 'PI'
         self.pos_x = 0
         self.pos_y = 0
-        self.width = 100
-        self.height = 50
+        self.width = 70
+        self.height = 35
         self.line = None
         self.charPositionInLine = None
         # provided clause (not supported yet)
@@ -378,8 +385,8 @@ class Start(object):
         self.inputString = ''
         self.pos_x = 0
         self.pos_y = 0
-        self.width = 100
-        self.height = 50
+        self.width = 70
+        self.height = 35
         # start transition is of type Transition
         self.transition = None
         # optional comment symbol
@@ -404,11 +411,11 @@ class Comment(object):
     def __init__(self):
         ''' Comment symbol '''
         # inputString is the comment value itself
-        self.inputString = 'Comment'
+        self.inputString = ''
         self.pos_x = 0
         self.pos_y = 0
-        self.width = 100
-        self.height = 50
+        self.width = 70
+        self.height = 35
         self.line = None
         self.charPositionInLine = None
         # optional hyperlink
@@ -422,7 +429,7 @@ class Comment(object):
 
 class State(object):
     ''' AST Entry for STATE symbols '''
-    def __init__(self, defName='Wait'):
+    def __init__(self, defName=''):
         ''' Used only for rendering backends - not for code generation '''
         # inputString contains possibly several states (and asterisk)
         self.inputString = defName
@@ -432,8 +439,8 @@ class State(object):
         self.charPositionInLine = None
         self.pos_x = 0
         self.pos_y = 0
-        self.width = 100
-        self.height = 50
+        self.width = 70
+        self.height = 35
         # list of type Input
         self.inputs = []
         # optional comment symbol
@@ -493,8 +500,8 @@ class Procedure(object):
         self.charPositionInLine = None
         # Set default coordinates and width/height
         self.pos_x = self.pos_y = 0
-        self.width = 100
-        self.height = 50
+        self.width = 70
+        self.height = 35
         # Optional hyperlink
         self.hyperlink = None
         # Local variables dictionnary (see Process)
